package com.ruoyi.system1.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system1.domain.CourseSection;
import com.ruoyi.system1.service.ICourseSectionService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 课程章节Controller
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@RestController
@RequestMapping("/system1/section")
public class CourseSectionController extends BaseController
{
    @Autowired
    private ICourseSectionService courseSectionService;

    /**
     * 查询课程章节列表
     */
    @PreAuthorize("@ss.hasPermi('system1:section:list')")
    @GetMapping("/list")
    public TableDataInfo list(CourseSection courseSection)
    {
        startPage();
        List<CourseSection> list = courseSectionService.selectCourseSectionList(courseSection);
        return getDataTable(list);
    }

    /**
     * 导出课程章节列表
     */
    @PreAuthorize("@ss.hasPermi('system1:section:export')")
    @Log(title = "课程章节", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CourseSection courseSection)
    {
        List<CourseSection> list = courseSectionService.selectCourseSectionList(courseSection);
        ExcelUtil<CourseSection> util = new ExcelUtil<CourseSection>(CourseSection.class);
        util.exportExcel(response, list, "课程章节数据");
    }

    /**
     * 获取课程章节详细信息
     */
    @PreAuthorize("@ss.hasPermi('system1:section:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(courseSectionService.selectCourseSectionById(id));
    }

    /**
     * 新增课程章节
     */
    @PreAuthorize("@ss.hasPermi('system1:section:add')")
    @Log(title = "课程章节", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CourseSection courseSection)
    {
        return toAjax(courseSectionService.insertCourseSection(courseSection));
    }

    /**
     * 修改课程章节
     */
    @PreAuthorize("@ss.hasPermi('system1:section:edit')")
    @Log(title = "课程章节", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CourseSection courseSection)
    {
        return toAjax(courseSectionService.updateCourseSection(courseSection));
    }

    /**
     * 删除课程章节
     */
    @PreAuthorize("@ss.hasPermi('system1:section:remove')")
    @Log(title = "课程章节", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(courseSectionService.deleteCourseSectionByIds(ids));
    }
}
