package com.ruoyi.system1.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system1.domain.Order1;
import com.ruoyi.system1.service.IOrder1Service;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 订单Controller
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@RestController
@RequestMapping("/system1/order1")
public class Order1Controller extends BaseController
{
    @Autowired
    private IOrder1Service order1Service;

    /**
     * 查询订单列表
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:list')")
    @GetMapping("/list")
    public TableDataInfo list(Order1 order1)
    {
        startPage();
        List<Order1> list = order1Service.selectOrder1List(order1);
        return getDataTable(list);
    }

    /**
     * 导出订单列表
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:export')")
    @Log(title = "订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Order1 order1)
    {
        List<Order1> list = order1Service.selectOrder1List(order1);
        ExcelUtil<Order1> util = new ExcelUtil<Order1>(Order1.class);
        util.exportExcel(response, list, "订单数据");
    }

    /**
     * 获取订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(order1Service.selectOrder1ById(id));
    }

    /**
     * 新增订单
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:add')")
    @Log(title = "订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Order1 order1)
    {
        return toAjax(order1Service.insertOrder1(order1));
    }

    /**
     * 修改订单
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:edit')")
    @Log(title = "订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Order1 order1)
    {
        return toAjax(order1Service.updateOrder1(order1));
    }

    /**
     * 删除订单
     */
    @PreAuthorize("@ss.hasPermi('system1:order1:remove')")
    @Log(title = "订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(order1Service.deleteOrder1ByIds(ids));
    }
}
