package com.ruoyi.system1.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system1.domain.ShopAdmin;
import com.ruoyi.system1.service.IShopAdminService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 店铺管理员Controller
 * 
 * @author ruoyi
 * @date 2025-05-08
 */
@RestController
@RequestMapping("/system1/admin")
public class ShopAdminController extends BaseController
{
    @Autowired
    private IShopAdminService shopAdminService;

    /**
     * 查询店铺管理员列表
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:list')")
    @GetMapping("/list")
    public TableDataInfo list(ShopAdmin shopAdmin)
    {
        startPage();
        List<ShopAdmin> list = shopAdminService.selectShopAdminList(shopAdmin);
        return getDataTable(list);
    }

    /**
     * 导出店铺管理员列表
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:export')")
    @Log(title = "店铺管理员", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ShopAdmin shopAdmin)
    {
        List<ShopAdmin> list = shopAdminService.selectShopAdminList(shopAdmin);
        ExcelUtil<ShopAdmin> util = new ExcelUtil<ShopAdmin>(ShopAdmin.class);
        util.exportExcel(response, list, "店铺管理员数据");
    }

    /**
     * 获取店铺管理员详细信息
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:query')")
    @GetMapping(value = "/{shopId}")
    public AjaxResult getInfo(@PathVariable("shopId") Long shopId)
    {
        return success(shopAdminService.selectShopAdminByShopId(shopId));
    }

    /**
     * 新增店铺管理员
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:add')")
    @Log(title = "店铺管理员", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ShopAdmin shopAdmin)
    {
        return toAjax(shopAdminService.insertShopAdmin(shopAdmin));
    }

    /**
     * 修改店铺管理员
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:edit')")
    @Log(title = "店铺管理员", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ShopAdmin shopAdmin)
    {
        return toAjax(shopAdminService.updateShopAdmin(shopAdmin));
    }

    /**
     * 删除店铺管理员
     */
    @PreAuthorize("@ss.hasPermi('system1:admin:remove')")
    @Log(title = "店铺管理员", businessType = BusinessType.DELETE)
	@DeleteMapping("/{shopIds}")
    public AjaxResult remove(@PathVariable Long[] shopIds)
    {
        return toAjax(shopAdminService.deleteShopAdminByShopIds(shopIds));
    }
}
