package com.ruoyi.system1.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system1.domain.UserCoupon;
import com.ruoyi.system1.service.IUserCouponService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 用户优惠券Controller
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@RestController
@RequestMapping("/system1/userCoupon")
public class UserCouponController extends BaseController
{
    @Autowired
    private IUserCouponService userCouponService;

    /**
     * 查询用户优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserCoupon userCoupon)
    {
        startPage();
        List<UserCoupon> list = userCouponService.selectUserCouponList(userCoupon);
        return getDataTable(list);
    }

    /**
     * 导出用户优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:export')")
    @Log(title = "用户优惠券", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserCoupon userCoupon)
    {
        List<UserCoupon> list = userCouponService.selectUserCouponList(userCoupon);
        ExcelUtil<UserCoupon> util = new ExcelUtil<UserCoupon>(UserCoupon.class);
        util.exportExcel(response, list, "用户优惠券数据");
    }

    /**
     * 获取用户优惠券详细信息
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(userCouponService.selectUserCouponById(id));
    }

    /**
     * 新增用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:add')")
    @Log(title = "用户优惠券", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserCoupon userCoupon)
    {
        return toAjax(userCouponService.insertUserCoupon(userCoupon));
    }

    /**
     * 修改用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:edit')")
    @Log(title = "用户优惠券", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserCoupon userCoupon)
    {
        return toAjax(userCouponService.updateUserCoupon(userCoupon));
    }

    /**
     * 删除用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('system1:userCoupon:remove')")
    @Log(title = "用户优惠券", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(userCouponService.deleteUserCouponByIds(ids));
    }
}
