package com.ruoyi.system1.service.impl;

import java.util.Date;
import java.util.List;

import com.ruoyi.system1.domain.UserCoupon;
import com.ruoyi.system1.mapper.UserCouponMapper;
import com.ruoyi.system1.util.SnowflakeIdWorker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system1.mapper.CouponMapper;
import com.ruoyi.system1.domain.Coupon;
import com.ruoyi.system1.service.ICouponService;

import javax.annotation.Resource;

/**
 * 优惠券Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@Service
public class CouponServiceImpl implements ICouponService 
{
    @Autowired
    private CouponMapper couponMapper;

    /**
     * 查询优惠券
     * 
     * @param id 优惠券主键
     * @return 优惠券
     */
    @Override
    public Coupon selectCouponById(Long id)
    {
        return couponMapper.selectCouponById(id);
    }

    /**
     * 查询优惠券列表
     * 
     * @param coupon 优惠券
     * @return 优惠券
     */
    @Override
    public List<Coupon> selectCouponList(Coupon coupon)
    {
        return couponMapper.selectCouponList(coupon);
    }

    /**
     * 新增优惠券
     * 
     * @param coupon 优惠券
     * @return 结果
     */
    @Resource
    private UserCouponMapper userCouponMapper;
    @Override
    public int insertCoupon(Coupon coupon)
    {
        SnowflakeIdWorker snowflakeIdWorker=new SnowflakeIdWorker(1,1);
        long l = snowflakeIdWorker.nextId();
        coupon.setId(l);
        couponMapper.insertCoupon(coupon);
        UserCoupon userCoupon=new UserCoupon();
        userCoupon.setId(snowflakeIdWorker.nextId());
        userCoupon.setUserId(coupon.getUserId());
        userCoupon.setCouponId(coupon.getId());
        userCoupon.setStatus(0);
        userCoupon.setGetTime(new Date());

        return  userCouponMapper.insertUserCoupon(userCoupon);
    }

    /**
     * 修改优惠券
     * 
     * @param coupon 优惠券
     * @return 结果
     */

    @Override
    public int updateCoupon(Coupon coupon)
    {
        return couponMapper.updateCoupon(coupon);
    }

    /**
     * 批量删除优惠券
     * 
     * @param ids 需要删除的优惠券主键
     * @return 结果
     */
    @Override
    public int deleteCouponByIds(Long[] ids)
    {
        return couponMapper.deleteCouponByIds(ids);
    }

    /**
     * 删除优惠券信息
     * 
     * @param id 优惠券主键
     * @return 结果
     */
    @Override
    public int deleteCouponById(Long id)
    {
        return couponMapper.deleteCouponById(id);
    }
}
