package com.ruoyi.system1.service.impl;

import java.util.List;

import com.ruoyi.system1.util.SnowflakeIdWorker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system1.mapper.CourseSectionMapper;
import com.ruoyi.system1.domain.CourseSection;
import com.ruoyi.system1.service.ICourseSectionService;

/**
 * 课程章节Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@Service
public class CourseSectionServiceImpl implements ICourseSectionService 
{
    @Autowired
    private CourseSectionMapper courseSectionMapper;

    /**
     * 查询课程章节
     * 
     * @param id 课程章节主键
     * @return 课程章节
     */
    @Override
    public CourseSection selectCourseSectionById(Long id)
    {
        return courseSectionMapper.selectCourseSectionById(id);
    }

    /**
     * 查询课程章节列表
     * 
     * @param courseSection 课程章节
     * @return 课程章节
     */
    @Override
    public List<CourseSection> selectCourseSectionList(CourseSection courseSection)
    {
        return courseSectionMapper.selectCourseSectionList(courseSection);
    }

    /**
     * 新增课程章节
     * 
     * @param courseSection 课程章节
     * @return 结果
     */
    @Override
    public int insertCourseSection(CourseSection courseSection)
    {
        SnowflakeIdWorker snowflakeIdWorker=new SnowflakeIdWorker(1,1);
        courseSection.setId(snowflakeIdWorker.nextId());
        return courseSectionMapper.insertCourseSection(courseSection);
    }

    /**
     * 修改课程章节
     * 
     * @param courseSection 课程章节
     * @return 结果
     */
    @Override
    public int updateCourseSection(CourseSection courseSection)
    {
        return courseSectionMapper.updateCourseSection(courseSection);
    }

    /**
     * 批量删除课程章节
     * 
     * @param ids 需要删除的课程章节主键
     * @return 结果
     */
    @Override
    public int deleteCourseSectionByIds(Long[] ids)
    {
        return courseSectionMapper.deleteCourseSectionByIds(ids);
    }

    /**
     * 删除课程章节信息
     * 
     * @param id 课程章节主键
     * @return 结果
     */
    @Override
    public int deleteCourseSectionById(Long id)
    {
        return courseSectionMapper.deleteCourseSectionById(id);
    }
}
