package com.ruoyi.system1.service.impl;

import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system1.domain.ShopAdmin;
import com.ruoyi.system1.mapper.ShopAdminMapper;
import com.ruoyi.system1.util.SnowflakeIdWorker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system1.mapper.ShopMapper;
import com.ruoyi.system1.domain.Shop;
import com.ruoyi.system1.service.IShopService;

import javax.annotation.Resource;

/**
 * 店铺Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@Service
public class ShopServiceImpl implements IShopService 
{
    @Autowired
    private ShopMapper shopMapper;

    /**
     * 查询店铺
     * 
     * @param id 店铺主键
     * @return 店铺
     */
    @Override
    public Shop selectShopById(Long id)
    {
        return shopMapper.selectShopById(id);
    }

    /**
     * 查询店铺列表
     * 
     * @param shop 店铺
     * @return 店铺
     */
    @Override
    public List<Shop> selectShopList(Shop shop)
    {
        return shopMapper.selectShopList(shop);
    }

    @Override
    public List<Shop> selectShopAll() {
        return shopMapper.selectShopAll();
    }

    /**
     * 新增店铺
     * 
     * @param shop 店铺
     * @return 结果
     */

    @Resource
    private ShopAdminMapper shopAdminMapper;
    @Override
    public int insertShop(Shop shop)
    {
        System.err.println(shop);
        SnowflakeIdWorker snowflakeIdWorker=new SnowflakeIdWorker(1,1);
        shop.setId(snowflakeIdWorker.nextId());
        shop.setCreateTime(new Date());
        shop.setCreateTime(DateUtils.getNowDate());
        shopMapper.insertShop(shop);
        System.err.println(shop);
        ShopAdmin shopAdmin=new ShopAdmin();
        shopAdmin.setShopId(shop.getId());
        shopAdmin.setUserId(shop.getAdminUserId());

        return shopAdminMapper.insertShopAdmin(shopAdmin);
    }

    /**
     * 修改店铺
     * 
     * @param shop 店铺
     * @return 结果
     */
    @Override
    public int updateShop(Shop shop)
    {
        return shopMapper.updateShop(shop);
    }

    /**
     * 批量删除店铺
     * 
     * @param ids 需要删除的店铺主键
     * @return 结果
     */
    @Override
    public int deleteShopByIds(Long[] ids)
    {
        return shopMapper.deleteShopByIds(ids);
    }

    /**
     * 删除店铺信息
     * 
     * @param id 店铺主键
     * @return 结果
     */
    @Override
    public int deleteShopById(Long id)
    {
        return shopMapper.deleteShopById(id);
    }
}
