package com.ruoyi.system1.service.impl;

import java.util.List;

import com.ruoyi.system1.util.SnowflakeIdWorker;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system1.mapper.UserCouponMapper;
import com.ruoyi.system1.domain.UserCoupon;
import com.ruoyi.system1.service.IUserCouponService;

/**
 * 用户优惠券Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-06
 */
@Service
public class UserCouponServiceImpl implements IUserCouponService 
{
    @Autowired
    private UserCouponMapper userCouponMapper;

    /**
     * 查询用户优惠券
     * 
     * @param id 用户优惠券主键
     * @return 用户优惠券
     */
    @Override
    public UserCoupon selectUserCouponById(Long id)
    {
        return userCouponMapper.selectUserCouponById(id);
    }

    /**
     * 查询用户优惠券列表
     * 
     * @param userCoupon 用户优惠券
     * @return 用户优惠券
     */
    @Override
    public List<UserCoupon> selectUserCouponList(UserCoupon userCoupon)
    {
        return userCouponMapper.selectUserCouponList(userCoupon);
    }

    /**
     * 新增用户优惠券
     * 
     * @param userCoupon 用户优惠券
     * @return 结果
     */
    @Override
    public int insertUserCoupon(UserCoupon userCoupon)
    {
        SnowflakeIdWorker snowflakeIdWorker=new SnowflakeIdWorker(1,1);
        userCoupon.setId(snowflakeIdWorker.nextId());
        return userCouponMapper.insertUserCoupon(userCoupon);
    }

    /**
     * 修改用户优惠券
     * 
     * @param userCoupon 用户优惠券
     * @return 结果
     */
    @Override
    public int updateUserCoupon(UserCoupon userCoupon)
    {
        return userCouponMapper.updateUserCoupon(userCoupon);
    }

    /**
     * 批量删除用户优惠券
     * 
     * @param ids 需要删除的用户优惠券主键
     * @return 结果
     */
    @Override
    public int deleteUserCouponByIds(Long[] ids)
    {
        return userCouponMapper.deleteUserCouponByIds(ids);
    }

    /**
     * 删除用户优惠券信息
     * 
     * @param id 用户优惠券主键
     * @return 结果
     */
    @Override
    public int deleteUserCouponById(Long id)
    {
        return userCouponMapper.deleteUserCouponById(id);
    }
}
