package com.ruoyi.common.utils;

import io.minio.*;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.stereotype.Component;
import org.springframework.web.multipart.MultipartFile;

import io.minio.MinioClient;

import javax.annotation.Resource;

@Component
public class MinioUtils {
    @Value("${minio.endpoint}")
    private String endpoint;
    @Value("${minio.accessKey}")
    private String accessKey;
    @Value("${minio.secretKey}")
    private String secretKey;
    @Value("${minio.bucketName}")
    private String bucketName;




    private MinioClient minioClient;


    /**
     * 初始化 MinIO 客户端
     */
    public void init() {
        try {
            System.out.println("MinIO 配置: endpoint=" + endpoint + ", bucket=" + bucketName);
            this.minioClient = MinioClient.builder()
                    .endpoint(endpoint)
                    .credentials(accessKey, secretKey)
                    .build();
        } catch (Exception e) {
            System.err.println("MinIO 客户端初始化失败: " + e.getMessage());
            e.printStackTrace();
        }
    }



    public String upload(MultipartFile file, String fileName) throws Exception {
        if (minioClient == null) init();
        // 检查存储桶是否存在
        boolean isExist = minioClient.bucketExists(BucketExistsArgs.builder().bucket(bucketName).build());
        if (!isExist) {
            minioClient.makeBucket(MakeBucketArgs.builder().bucket(bucketName).build());
        }
        // 上传文件
        minioClient.putObject(PutObjectArgs.builder()
                .bucket(bucketName)
                .object(fileName)
                .stream(file.getInputStream(), file.getSize(), -1)
                .contentType(file.getContentType())
                .build());
        return endpoint + "/" + bucketName + "/" + fileName;
    }



}